@@ -53,13 +53,11 @@ class GWENVIEWLIB_EXPORT AbstractImageOperation : public QObject
     Q_OBJECT
 public:
     AbstractImageOperation();
-    virtual ~AbstractImageOperation();
+    ~AbstractImageOperation() override;
 
     void applyToDocument(Document::Ptr);
     Document::Ptr document() const;
 
-    void finishUndoJob();
-
 protected:
     virtual void redo() = 0;
     virtual void undo()
