@@ -18,7 +18,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
 #include "contextmanager.h"
-#include "contextmanager.h"
 
 // Qt
 #include <QItemSelectionModel>
@@ -51,15 +50,18 @@ struct ContextManagerPrivate
     QUrl mTargetDirUrl;
 
     bool mSelectedFileItemListNeedsUpdate;
-    QSet<QByteArray> mQueuedSignals;
+    using Signal = void (ContextManager::*)();
+    QVector<Signal> mQueuedSignals;
     KFileItemList mSelectedFileItemList;
 
     bool mDirListerFinished = false;
     QTimer* mQueuedSignalsTimer;
 
-    void queueSignal(const QByteArray& signal)
+    void queueSignal(Signal signal)
     {
-        mQueuedSignals << signal;
+        if (!mQueuedSignals.contains(signal)) {
+            mQueuedSignals << signal;
+        }
         mQueuedSignalsTimer->start();
     }
 
@@ -120,7 +122,7 @@ ContextManager::ContextManager(SortedDirModel* dirModel, QObject* parent)
     connect(d->mDirModel->dirLister(), SIGNAL(redirection(QUrl)),
             SLOT(slotDirListerRedirection(QUrl)));
 
-    connect(d->mDirModel->dirLister(), static_cast<void (KDirLister::*)()>(&KDirLister::completed), this, &ContextManager::slotDirListerCompleted);
+    connect(d->mDirModel->dirLister(), QOverload<>::of(&KDirLister::completed), this, &ContextManager::slotDirListerCompleted);
 
     d->mSelectionModel = new QItemSelectionModel(d->mDirModel);
 
@@ -165,7 +167,7 @@ void ContextManager::setCurrentUrl(const QUrl &currentUrl)
     }
 
     d->mSelectedFileItemListNeedsUpdate = true;
-    currentUrlChanged(currentUrl);
+    emit currentUrlChanged(currentUrl);
 }
 
 KFileItemList ContextManager::selectedFileItemList() const
@@ -187,9 +189,9 @@ void ContextManager::setCurrentDirUrl(const QUrl &_url)
         d->mDirListerFinished = false;
     } else {
         d->mCurrentDirUrl.clear();
-        d->mDirModel->dirLister()->clear();
+        emit d->mDirModel->dirLister()->clear();
     }
-    currentDirUrlChanged(url);
+    emit currentDirUrlChanged(url);
 }
 
 QUrl ContextManager::currentDirUrl() const
@@ -235,7 +237,7 @@ void ContextManager::slotDirModelDataChanged(const QModelIndex& topLeft, const Q
     Q_FOREACH(const QModelIndex & index, shortList) {
         if (longList.contains(index)) {
             d->mSelectedFileItemListNeedsUpdate = true;
-            d->queueSignal("selectionDataChanged");
+            d->queueSignal(&ContextManager::selectionDataChanged);
             return;
         }
     }
@@ -247,7 +249,7 @@ void ContextManager::slotSelectionChanged()
     if (!d->mSelectionModel->hasSelection()) {
         setCurrentUrl(QUrl());
     }
-    d->queueSignal("selectionChanged");
+    d->queueSignal(&ContextManager::selectionChanged);
 }
 
 void Gwenview::ContextManager::slotCurrentChanged(const QModelIndex& index)
@@ -258,8 +260,8 @@ void Gwenview::ContextManager::slotCurrentChanged(const QModelIndex& index)
 
 void ContextManager::emitQueuedSignals()
 {
-    Q_FOREACH(const QByteArray & signal, d->mQueuedSignals) {
-        QMetaObject::invokeMethod(this, signal.data());
+    Q_FOREACH(ContextManagerPrivate::Signal signal, d->mQueuedSignals) {
+        emit (this->*signal)();
     }
     d->mQueuedSignals.clear();
 }
