@@ -43,19 +43,19 @@ class GWENVIEWLIB_EXPORT BalooSemanticInfoBackend : public AbstractSemanticInfoB
     Q_OBJECT
 public:
     explicit BalooSemanticInfoBackend(QObject* parent);
-    ~BalooSemanticInfoBackend() Q_DECL_OVERRIDE;
+    ~BalooSemanticInfoBackend() override;
 
-    TagSet allTags() const Q_DECL_OVERRIDE;
+    TagSet allTags() const override;
 
-    void refreshAllTags() Q_DECL_OVERRIDE;
+    void refreshAllTags() override;
 
-    void storeSemanticInfo(const QUrl&, const SemanticInfo&) Q_DECL_OVERRIDE;
+    void storeSemanticInfo(const QUrl&, const SemanticInfo&) override;
 
-    void retrieveSemanticInfo(const QUrl&) Q_DECL_OVERRIDE;
+    void retrieveSemanticInfo(const QUrl&) override;
 
-    QString labelForTag(const SemanticInfoTag&) const Q_DECL_OVERRIDE;
+    QString labelForTag(const SemanticInfoTag&) const override;
 
-    SemanticInfoTag tagForLabel(const QString&) Q_DECL_OVERRIDE;
+    SemanticInfoTag tagForLabel(const QString&) override;
 
 private:
     struct Private;
